(v0.12.10)=
### 0.12.10 {small}`2026-02-06`

#### Miscellaneous changes

- Add {attr}`anndata.settings.copy_on_write_X` to allow for forward-compatibility with future copy-on-write behavior (release `0.13`). Currently, setting {attr}`~anndata.AnnData.X` on a view implicitly updates the object from which the view was created. {user}`ilan-gold` ({pr}`2327`)
